(function () {
	var cfg = typeof __WR360GalleryDefaults !== 'undefined' ? __WR360GalleryDefaults : {
		menuSpacing: 20,
		menuNavOffset: 0,
		slideSpeed: 700,
	};

	cfg.menuNavOffset = cfg.menuNavOffset || 0;

	var gallery = document.querySelector('.wr360-gallery');
	if (gallery) {
		if (cfg.largeThumbSize)
			gallery.style.setProperty('--large-thumb-size', cfg.largeThumbSize + 'px');
		if (cfg.smallThumbSize)
			gallery.style.setProperty('--small-thumb-size', cfg.smallThumbSize + 'px');
		if (cfg.thumbBackground)
			gallery.style.setProperty('--thumb-background', cfg.thumbBackground);
		if (cfg.thumbBorderColor)
			gallery.style.setProperty('--thumb-border-color', cfg.thumbBorderColor);
		if (cfg.thumbBorderColorSel)
			gallery.style.setProperty('--thumb-border-color-sel', cfg.thumbBorderColorSel);
	}

	var menu = new Swiper('.wr360-swiper-menu', {
		slidesPerView: 'auto',
		spaceBetween: cfg.menuSpacing,
		navigation: {
			nextEl: '.wr360-nav-right',
			prevEl: '.wr360-nav-left',
		}
	});

	var view = new Swiper('.wr360-swiper-view', {
		slidesPerView: 1,
		speed: cfg.slideSpeed,
		allowTouchMove: true,
		navigation: {
			nextEl: '.wr360-main-right',
			prevEl: '.wr360-main-left',
		},
		on: {
			init: function() {
				initAll(this);
			}
		}
	});

	function initAll(view) {
		var wr360s = [],
			closeZoom = document.querySelector('.wr360-close-zoom'),
			navigation = document.querySelector('.wr360-gal-navigation'),
			mainSlides = view.$wrapperEl[0].querySelectorAll('.swiper-slide'),
			menuSlides = menu.$wrapperEl[0].querySelectorAll('.swiper-slide'),
			slideNum = menuSlides.length,
			isZoomed = false;

		function setSelectedMenu(selectedIndex) {
			for (var slideIdx = 0; slideIdx < slideNum; slideIdx++) {
				menu.slides[slideIdx].classList.remove('swiper-current-slide');
			}

			menu.slides[selectedIndex].classList.add('swiper-current-slide');
		}

		function toggleZoom() {
			if (isZoomed) {
				gallery.classList.remove('wr360-gallery-zoom');
				document.body.style.overflow = '';
			}
			else {
				gallery.classList.add('wr360-gallery-zoom');
				document.body.style.overflow = 'hidden';
			}

			isZoomed = !isZoomed;
			view.zoom.enabled = isZoomed;

			menu.update();
			navigation.style.maxWidth = isZoomed ?
				(slideNum * (menuSlides[0].clientWidth + cfg.menuSpacing + 2/*border*/)) + cfg.menuNavOffset - cfg.menuSpacing + 'px' : '100%';

			menu.update();
			view.update();

			for (var apiIdx = 0; apiIdx < wr360s.length; apiIdx++) {
				wr360s[apiIdx].updateDimensions();
			}
		}

		for (var slideIdx = 0; slideIdx < slideNum; slideIdx++) {
			var slide = mainSlides[slideIdx];

			if (slide.getAttribute('data-wr360-cfg')) {
				slide.addEventListener('pointerdown', function(e) {
					e.stopPropagation();
				});
			}
			else {
				slide.addEventListener('click', function() {
					toggleZoom();
				}, false);
			}
		}

		for (var slideIdx = 0; slideIdx < slideNum; slideIdx++) {
			menuSlides[slideIdx].addEventListener('click', function() {
				view.slideTo(parseInt(this.dataset.index), isZoomed ? 0 : cfg.slideSpeed);
			}, false);
		}

		document.addEventListener('keydown', function(e) {
			if (e.keyCode === 27 && isZoomed)
				toggleZoom();
		});

		closeZoom.addEventListener('click', function() {
			toggleZoom();
		});

		view.on('slideChange', function(slide) {
			initViewForSlide(this.activeIndex);
			menu.slideTo(this.activeIndex);
			setSelectedMenu(this.activeIndex);

			var previousSlide = this.slides[view.previousIndex];
			if (previousSlide) {
				if (previousSlide.classList.contains('videoSlide')) {
					var youtubePlayer = previousSlide.querySelector('iframe');
					if (youtubePlayer)
						youtubePlayer.contentWindow.postMessage('{"event":"command","func":"stopVideo","args":""}', '*');
				}
			}
		});

		function initViewForSlide(index) {
			var slide = mainSlides[index];
			var configUrl = slide.getAttribute('data-wr360-cfg');
			if (!configUrl)
				return;

			if (!slide.getAttribute('data-wr360-loaded')) {
				var ir = WR360.ImageRotator.Create('view' + index);

				ir.settings.graphicsPath = cfg.graphicsPath;
				ir.settings.configFileURL = configUrl;
				ir.settings.rootPath = slide.getAttribute('data-wr360-root');
				ir.settings.googleEventTracking = !!cfg.useAnalytics;
				ir.settings.viewName = slide.getAttribute('data-wr360-name');
				ir.licenseFileURL = cfg.licensePath;
				ir.settings.apiReadyCallback = function(api, isFullScreen) {
					if (!isFullScreen) {
						wr360s.push(api);
						api.updateDimensions();
					}
					if (cfg.callback) {
						var fn = window[cfg.callback];
						if (typeof fn === 'function')
							fn(api, isFullScreen, ir.settings.viewName);
					}
				}

				ir.runImageRotator();

				slide.setAttribute('data-wr360-loaded', 1);
			}
		}

		initViewForSlide(0);
		setSelectedMenu(0);
	}
})();