<?php
/*
    Author: WebRotate 360 LLC
    Author URI: https://www.webrotate360.com
    License: GPLv2
*/

if (!defined("ABSPATH"))
    exit;

class WR360WooCommerce
{
    private $woo_version;
    private $views = [];
    private $images = [];
    private $plugin_config;

    public function __construct()
    {
        $this->woo_version = $this->get_woocommerce_version();
        $this->plugin_config = new WR360DefaultsConfig();
        $this->plugin_config->init_header();

        if (is_admin()) {
            add_action("woocommerce_product_write_panel_tabs", array($this, "wr360_options_tab"));
            add_action("woocommerce_product_write_panels", array($this, "wr360_tab_panel"));
            add_action("woocommerce_process_product_meta", array($this, "wr360_save_product"));
        } else {
            add_action('loop_start', [$this, 'wr360_init_integration'], 20);
        }
    }

    public function wr360_init_integration()
    {
        remove_action("woocommerce_before_single_product_summary", "woocommerce_show_product_images", 20);
        remove_action("woocommerce_product_thumbnails", "woocommerce_show_product_thumbnails", 20);
        add_action("woocommerce_before_single_product_summary", [$this, "wr360_init_gallery"], 20);
    }

    public function wr360_init_gallery()
    {
        $this->init_views();
        $this->init_images();
        $view_count = count($this->views);
        $image_count = count($this->images);

        if ($image_count === 0 && $view_count === 0) {
            return;
        }

        if ($view_count === 1 && $image_count === 0) {
            $html = "<div class='images webrotate360'>";
            $html .= $this->get_single_view_html($this->views[0]["config"]);
            $html .= "</div>";
            echo $html;
            return;
        }

        $html = $this->get_gallery_html($image_count, $view_count);
        if ($html)
            echo $html;
    }

    private function init_images()
    {
        global $product, $post;

        $post_thumb_id = get_post_thumbnail_id($post->ID);
        $this->images = $product->get_gallery_image_ids();
        array_unshift($this->images, $post_thumb_id);
    }

    private function init_views()
    {
        global $post;

        $wr360_config = esc_url(get_post_meta($post->ID, "_wr360config", true));
        $wr360_root = esc_url(get_post_meta($post->ID, "_wr360root", true));

        if ($wr360_config || $wr360_root) {
            $config = clone $this->plugin_config;
            $config->init_shortcode(array("name" => $post->ID, "config" => $wr360_config, "rootpath" => $wr360_root), false);
            $this->views[] = ["config" => $config];
        }
    }

    private function get_empty_image_src($regImageSize)
    {
        $firstImage = wp_get_attachment_image_src($this->images[0], $regImageSize);
        return "data:image/svg+xml;utf8,<svg xmlns='http://www.w3.org/2000/svg' x='0' y='0' width='" . $firstImage[1] . "px' height='" . $firstImage[2] . "px'/>";
    }

    private function append_view_html(&$slides, &$thumbs, &$counter, $regImageSize)
    {
        foreach ($this->views as $view) {
            $config = $view["config"];
            $slides .=
                '<div class="swiper-slide" data-wr360-cfg="' . $config->config . '" data-wr360-root="' . $config->rootPath . '" data-index="' . $counter . '" data-wr360-name="' . $this->get_product_name($config->name) . '">
                    <div class="wr360-flex-container">
                        <img src="' . $this->get_empty_image_src($regImageSize) . '">
                        <div class="wr360-view-container">
                            <div id="view' . $counter . '" class="wr360_player" style="background-color:' . $config->background . ';">
                            </div>
                        </div>
                    </div>
                </div>';

            $thumbs .=
                '<div class="swiper-slide" data-index="' . $counter . '">
                    <img src="' . $this->plugin_config->wooThumb360Url . '"/>
                </div>';

            $counter++;
        }
    }

    private function get_gallery_html($image_count, $view_count)
    {
        $regImageSize = "large";
        $hiddenNavClass = $image_count === 1 && $view_count === 0 ? "wr360-nav-hidden" : "";
        $hiddenArrowsClass = "";//"wr360-no-arrows";

        $html =
            '<div class="images webrotate360">
                <div class="wr360-gallery ' . $hiddenNavClass . '">
                    <button class="wr360-close-zoom"><div></div><div></div></button>';
        $html .=
            '<div class="wr360-gal-main ' . $hiddenArrowsClass . '">
                <div class="wr360-arrow-container-left">
					<button class="wr360-arrow wr360-main-left"></button>
				</div>
                <div class="wr360-swiper-view">
                    <div class="swiper-wrapper">';

        $imageSlides = "";
        $imageThumbs = "";
        $counter = 0;

        if ($this->plugin_config->wooThumbPosition === "First") {
            $this->append_view_html($imageSlides, $imageThumbs, $counter, $regImageSize);
        }

        foreach ($this->images as $image) {
            $image_view = wp_get_attachment_image_src($image, $regImageSize);
            $image_thumb = wp_get_attachment_image_src($image, "woocommerce_thumbnail");
            $image_srcset = "";//wp_get_attachment_image_srcset($image, 'medium');

            $imageSlides .=
                '<div class="swiper-slide" data-index="' . $counter . '">
                    <div class="wr360-flex-container">
                        <img src="' . $image_view[0] . '" srcset="' . $image_srcset . '"/>
                    </div>
                </div>';

            $imageThumbs .=
                '<div class="swiper-slide" data-index="' . $counter . '">
                    <img src="' . $image_thumb[0] . '"/>
                </div>';

            $counter++;

            if ($this->plugin_config->wooThumbPosition === "Second" && $counter === 1) {
                $this->append_view_html($imageSlides, $imageThumbs, $counter, $regImageSize);
            }
        }

        if ($this->plugin_config->wooThumbPosition === "Last") {
            $this->append_view_html($imageSlides, $imageThumbs, $counter, $regImageSize);
        }

        $html .= $imageSlides;
        $html .= '</div></div><div class="wr360-arrow-container-right">
					<button class="wr360-arrow wr360-main-right"></button>
				</div></div>';
        $html .=
            '<div class="wr360-gal-navigation">
				<button class="wr360-arrow wr360-nav-left"></button>
				<div class="wr360-swiper-menu">
					<div class="swiper-wrapper">';

        $html .= $imageThumbs;
        $html .= '</div></div><button class="wr360-arrow wr360-nav-right"></button></div>';
        $html .= '</div></div>';

        if ($view_count > 0) {
            $config = $this->views[0]["config"];
            $html .= sprintf('<script> var __WR360GalleryDefaults = {
                    licensePath: "%s", 
                    graphicsPath: "%s", 
                    useAnalytics: %s, 
                    callback: "%s",
                    menuSpacing: %s,
                    smallThumbSize: %s,
                    largeThumbSize: %s,
                    thumbBackground: "%s",
                    thumbBorderColor: "%s",
                    thumbBorderColorSel: "%s",
                    slideSpeed: %s
                };</script>',
                $config->licensePath,
                $config->graphicsPath,
                $config->useGoogleEvents ? "true" : "false",
                $config->callback,
                $config->wooThumbSpacing,
                $config->wooThumbSmallSz,
                $config->wooThumbLargeSz,
                $config->wooThumbBackground,
                $config->wooThumbBorderColor,
                $config->wooThumbBorderColorSel,
                $config->wooSlideSpeed
            );
        }

        return $html;
    }

    private function get_single_view_html($config)
    {
        $html = "<div id='%s' class='webrotate360 wr360embed' style='width:%s; height:%s;' data-imagerotator='{";
        $html .= '"onready":"%s", "graphics":"%s", "licfile":"%s", "rootpath":"%s", "xmlfile":"%s", "basewidth":%s, "events":%s, "name":"%s", "minheight":%s, "background":"%s"';
        $html .= "}'></div>";

        $html = sprintf(
            $html,
            'wr360woo_' . $config->name,
            (strpos($config->viewerWidth, '%') === FALSE) ? $config->viewerWidth . 'px' : $config->viewerWidth,
            $config->viewerHeight . "px",
            $config->callback,
            $config->graphicsPath,
            $config->licensePath,
            $config->rootPath,
            $config->config,
            $config->baseWidth,
            $config->useGoogleEvents ? "true" : "false",
            $this->get_product_name($config->name),
            $config->minHeight,
            $config->background);

        return $html;
    }

    private function get_product_name($configName)
    {
        global $product;

        $name = preg_replace('/\s+/', '', $product->get_sku());
        if (!$name) {
            $name = 'wr360woo_' . $configName;
        }

        return $name;
    }

    public function wr360_save_product($post_id)
    {
        if (isset($_POST["_wr360config"])) {
            update_post_meta($post_id, "_wr360config", esc_url($_POST["_wr360config"]));
        }

        if (isset($_POST["_wr360root"])) {
            update_post_meta($post_id, "_wr360root", esc_url($_POST["_wr360root"]));
        }
    }

    public function wr360_options_tab()
    {
        echo '<li class="custom_tab"><a href="#webrotate360woo_tab_data" id="webrotate360woo_tab"><span>WebRotate 360</span></a></li>';
    }

    public function wr360_tab_panel()
    {
        echo '<style type="text/css">a#webrotate360woo_tab:before{content: "\f463" !important;}</style>
            <div id="webrotate360woo_tab_data" class="panel woocommerce_options_panel"><div class="options_group">';

        woocommerce_wp_text_input(array(
            "id" => "_wr360config",
            "label" => "Config File URL",
            "placeholder" => "",
            "desc_tip" => true,
            "description" => "Config File URL"
        ));

        woocommerce_wp_text_input(array(
            "id" => "_wr360root",
            "label" => "Root Path",
            "placeholder" => "",
            "desc_tip" => true,
            "description" => "Root Path"
        ));

        echo "</div></div>";
    }

    private function get_woocommerce_version()
    {
        if (!function_exists("get_plugins")) {
            require_once(ABSPATH . "wp-admin/includes/plugin.php");
        }

        $plugin_folder = get_plugins("/" . "woocommerce");
        $plugin_file = "woocommerce.php";

        $version = $plugin_folder[$plugin_file]["Version"];
        if (isset($version)) {
            return $version;
        }

        return null;
    }
}