<?php
    if (!defined("ABSPATH"))
        exit;
?>

<div class="wrap">
    <h2>WebRotate 360 Product Viewer</h2>
    <form method="post" action="options.php">
        <p>Shortcode overview and examples are available on the plugin page <a href="https://www.webrotate360.com/products/cms-and-e-commerce-plugins/plugin-for-wordpress.aspx" target="_blank">here</a> and via this <a href="https://www.360-product-views.com/wordpress/" target="_blank">demo website</a>.
        If you haven't used WebRotate 360 Product Viewer before, download our <a href="https://www.webrotate360.com/products/webrotate-360-product-viewer.aspx" target="_blank">free software</a> (Windows or macOS) and follow this <a href="https://www.youtube.com/watch?v=W3uFpXy1ne4" target="_blank">YouTube video</a> or check out our <a href="https://www.webrotate360.com/Downloads/Resources/Readme.pdf" target="_blank">user guide</a> on how to create the product spins on your computer which you can then upload to your WordPress installation via FTP or use our optimized <a href="https://www.webrotate360.com/services/pixriot.aspx" target="_blank">PixRiot</a> cloud hosting. Note that you only need to upload a single folder that is created under 360_assets in the published folder of your SpotEditor project upon publish.</p>
        <p style="margin-bottom:50px"><b>IMPORTANT:</b> all files and folders are deleted from the WebRotate360 plugin folder by WordPress automatically upon the plugin update, so if you upload your WebRotate 360 assets (or a license file) under the plugin folder,
           they will be deleted upon the plugin update. We recommend to store these files outside of the WebRotate 360 plugin folder.
           If you have any questions or issues, email us at <a href="mailto:support@webrotate360.com">support@webrotate360.com</a> or visit our <a href="https://360-product-views.com/forum/" target="_blank">forum</a> and we would be happy to assist.
        </p>
        <h3>Shortcode settings</h3>
        <?php settings_fields("webrotate360-settings-group") ?>
        <?php do_settings_sections("webrotate360-settings-group") ?>
        <table class="form-table">
            <tr valign="top">
                <th scope="row">Viewer Width (px or %)</th>
                <td>
                    <input type="text" name="wr360_viewer_width" value="<?php echo get_option('wr360_viewer_width'); ?>"/>
                    <p class="description">Default viewer width. Can be relative (e.g. 100%) when used in wr360embed shortcodes.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Viewer Height (px or %)</th>
                <td>
                    <input type="text" name="wr360_viewer_height" value="<?php echo get_option('wr360_viewer_height'); ?>"/>
                    <p class="description">Default viewer height. Can be relative (e.g. 100%) when used in wr360embed shortcodes.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Base Width (px)</th>
                <td>
                    <input type="number" step="1" min="0" max="10000" name="wr360_viewer_basewidth" value="<?php echo get_option('wr360_viewer_basewidth'); ?>"/>
                    <p class="description">Enter viewer width when it's viewed on a desktop screen (Base Width) to force viewer to scale its height when viewed on small screen devices in wr360embed shortcodes.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Minimum Height (px)</th>
                <td>
                    <input type="number" step="1" min="0" max="10000" name="wr360_viewer_minheight" value="<?php echo get_option('wr360_viewer_minheight'); ?>"/>
                    <p class="description">If Base Width is set, this is a minimum viewer height in pixel (e.g 300px).</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Viewer Skin</th>
                <?php
                    $viewerSkin = get_option("wr360_viewer_skin");
                    $viewerSkins = array("basic", "thin", "round", "retina", "empty", "zoom_light", "zoom_dark");
                ?>
                <td>
                    <select id="wr360_viewer_skin" name="wr360_viewer_skin">
                        <?php foreach($viewerSkins as $skin):?>
                            <?php $selected = ($viewerSkin == $skin) ? 'selected="selected"' : '' ?>
                            <option value="<?php echo $skin?>" <?php echo $selected ?> ><?php echo $skin ?></option>
                        <?php endforeach?>
                    </select>
                    <p class="description">Default WebRotate 360 Product Viewer skins.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Popup Skin</th>
                <?php
                    $popupSkin = get_option("wr360_popup_skin");
                    $popupSkins = array("light_clean", "dark_clean", "pp_default", "light_rounded", "dark_rounded", "dark_square", "light_square", "facebook");
                ?>
                <td>
                    <select id="wr360_popup_skin" name="wr360_popup_skin">
                        <?php foreach($popupSkins as $skin):?>
                            <?php $selected = ($popupSkin == $skin) ? 'selected="selected"' : '' ?>
                            <option value="<?php echo $skin?>" <?php echo $selected ?> ><?php echo $skin ?></option>
                        <?php endforeach?>
                    </select>
                    <p class="description">Popup skins for wr360popup shortcodes.</p>
                </td>
            </tr>
        </table>
        <?php if (class_exists("WooCommerce")):?>
            <h3>WooCommerce settings</h3>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Position in product gallery</th>
                    <?php
                        $savedOption = get_option("wr360_gallery_woo_thumb_position");
                        $positionOptions = array("First", "Second", "Last");
                    ?>
                    <td>
                        <select id="wr360_gallery_woo_thumb_position" name="wr360_gallery_woo_thumb_position">
                            <?php foreach($positionOptions as $option):?>
                                <?php $selected = $option === $savedOption ? 'selected="selected"' : '' ?>
                                <option value="<?php echo $option?>" <?php echo $selected ?> ><?php echo $option ?></option>
                            <?php endforeach?>
                        </select>
                        <p class="description">Placement of a WebRotate 360 view (if configured) in product gallery.</p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Slide Speed</th>
                    <td>
                        <input type="number" step="1" min="0" max="5000" name="wr360_gallery_woo_slide_speed" value="<?php echo get_option('wr360_gallery_woo_slide_speed'); ?>"/>
                        <p class="description">Time in milliseconds to complete transition between two slides.</p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Large Thumbnail Size</th>
                    <td>
                        <input type="number" step="1" min="10" max="500" name="wr360_gallery_woo_thumb_large" value="<?php echo get_option('wr360_gallery_woo_thumb_large'); ?>"/>
                        <p class="description">Pixel size of gallery thumbnails when viewed on desktop computers and tablets (browser width > 800px).</p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Small Thumbnail Size</th>
                    <td>
                        <input type="number" step="1" min="10" max="500" name="wr360_gallery_woo_thumb_small" value="<?php echo get_option('wr360_gallery_woo_thumb_small'); ?>"/>
                        <p class="description">Pixel size of gallery thumbnails when viewed on smart phones (browser width < 800px).</p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Thumbnail Spacing</th>
                    <td>
                        <input type="number" step="1" min="0" max="500" name="wr360_gallery_woo_thumb_spacing" value="<?php echo get_option('wr360_gallery_woo_thumb_spacing'); ?>"/>
                        <p class="description">Pixel distance between thumbnails.</p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Thumbnail Background</th>
                    <td>
                        <input type="text" name="wr360_gallery_woo_thumb_background" class="wr360-color-popup" value="<?php echo get_option('wr360_gallery_woo_thumb_background'); ?>"/>
                        <p class="description">Color of thumbnail background. Default is transparent.</p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Thumbnail Border Color</th>
                    <td>
                        <input type="text" name="wr360_gallery_woo_thumb_border_color" class="wr360-color-popup" value="<?php echo get_option('wr360_gallery_woo_thumb_border_color'); ?>"/>
                        <input type="text" name="wr360_gallery_woo_thumb_border_color_sel" class="wr360-color-popup" value="<?php echo get_option('wr360_gallery_woo_thumb_border_color_sel'); ?>"/>
                        <p class="description">Color of thumbnail border (#1 when not selected, #2 when selected).</p>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Thumbnail Graphic URL</th>
                    <td>
                        <input type="text" name="wr360_gallery_woo_thumb_360_url" class="regular-text" value="<?php echo get_option('wr360_gallery_woo_thumb_360_url'); ?>"/>
                        <p class="description">Location of 360 thumbnail graphic file for product gallery.</p>
                    </td>
                </tr>
            </table>
        <?php endif ?>
        <h3>Advanced settings</h3>
        <table class="form-table">
             <tr valign="top">
                <th scope="row">Graphics Path</th>
                <td>
                    <input type="text" name="wr360_graphics_path" class="regular-text" value="<?php echo get_option('wr360_graphics_path'); ?>"/>
                    <p class="description">If using custom hotspot indicators, upload them to a folder in your WordPress installation or <a href="https://www.webrotate360.com/services/pixriot.aspx" target="_blank">PixRiot</a> and enter the URL of this folder here.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Viewer Background</th>
                <td>
                    <input type="text" name="wr360_background_color" class="wr360-color-popup" value="<?php echo get_option('wr360_background_color'); ?>"/>
                    <p class="description">Color of viewer background. Default is White.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Master Config URL (PRO)</th>
                <td>
                    <input type="text" name="wr360_master_config" class="regular-text" value="<?php echo get_option('wr360_master_config'); ?>"/>
                    <p class="description">When set, the same viewer XML config file (Master Config) can be used in multiple WebRotate 360 views in shortcodes and WooCommerce gallery. See #7 <a href="https://www.webrotate360.com/products/cms-and-e-commerce-plugins/plugin-for-wordpress-and-woocommerce.aspx?section=Installation" target="_blank">here</a> for more details.
                    </p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">Google Analytics (PRO)</th>
                <td>
                    <?php $checkedVal = get_option('wr360_use_googleevents');?>
                    <?php $checkedFlg = ($checkedVal) ? 'checked="checked"' : '' ?>
                    <label for="wr360_use_googleevents">
                        <input type="checkbox" id="wr360_use_googleevents" name="wr360_use_googleevents" <?php echo $checkedFlg; ?>/>
                        Enable analytics
                    </label>
                    <p class="description">Enable Google Analytics events to track user engagement when interacting with WebRotate 360 views.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">License URL (PRO)</th>
                <td>
                    <input type="text" name="wr360_license_path" class="regular-text" value="<?php echo get_option('wr360_license_path'); ?>"/>
                    <p class="description">URL of license.lic on this server (PRO and Enterprise). Purchase <a href="https://www.webrotate360.com/pricing.aspx" target="_blank">here</a>.</p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">API Ready Callback</th>
                <td>
                    <input type="text" name="wr360_api_ready_callback" class="regular-text" value="<?php echo get_option('wr360_api_ready_callback'); ?>"/>
                    <p class="description">To integrate viewer API, enter the name of your JavaScript callback. The callback receives three parameters: API object, isFullScreen flag and a shortcode name or WooCommerce SKU (e.g. function yourCallbackName(api, isFullScreen, name){}). </p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row">PrettyPhoto lightbox</th>
                <td>
                    <?php $checkedVal = get_option('wr360_prettyphoto_off');?>
                    <?php $checkedFlg = ($checkedVal) ? 'checked="checked"' : '' ?>
                    <label for="wr360_prettyphoto_off">
                        <input type="checkbox" id="wr360_prettyphoto_off" name="wr360_prettyphoto_off" <?php echo $checkedFlg; ?>/>
                        Disable
                    </label>
                    <p class="description">Disable the loading of prettyPhoto scripts that come with the plugin and used in wr360popup shortcode.</p>
                </td>
            </tr>

        </table>
        <?php submit_button() ?>
    </form>
</div>